package javax.swing.plaf.basic;

import java.awt.event.ActionEvent;
import sun.swing.UIAction;
import sun.swing.SwingUtilities2;
import javax.swing.RowSorter;
import java.awt.event.FocusEvent;
import java.util.Enumeration;
import javax.swing.table.TableCellRenderer;
import java.awt.Graphics;
import java.awt.Component;
import javax.swing.table.TableColumnModel;
import java.awt.Point;
import java.awt.Dimension;
import javax.swing.JViewport;
import javax.swing.table.TableColumn;
import java.awt.Rectangle;
import javax.swing.JTable;
import java.awt.Container;
import javax.swing.JScrollPane;
import java.awt.event.MouseEvent;
import javax.swing.SwingUtilities;
import sun.swing.DefaultLookup;
import javax.swing.InputMap;
import javax.swing.LookAndFeel;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import java.awt.event.FocusListener;
import javax.swing.event.MouseInputListener;
import javax.swing.CellRendererPane;
import javax.swing.table.JTableHeader;
import java.awt.Cursor;
import javax.swing.plaf.TableHeaderUI;

public class BasicTableHeaderUI extends TableHeaderUI
{
    private static Cursor resizeCursor;
    protected JTableHeader header;
    protected CellRendererPane rendererPane;
    protected MouseInputListener mouseInputListener;
    private int rolloverColumn;
    private int selectedColumnIndex;
    private static FocusListener focusListener;
    
    public BasicTableHeaderUI() {
        this.rolloverColumn = -1;
        this.selectedColumnIndex = 0;
    }
    
    protected MouseInputListener createMouseInputListener() {
        return new BasicTableHeaderUI.MouseInputHandler();
    }
    
    public static ComponentUI createUI(JComponent component) {
        return new BasicTableHeaderUI();
    }
    
    @Override
    public void installUI(JComponent component) {
        this.header = (JTableHeader)component;
        this.rendererPane = new CellRendererPane();
        this.header.add(this.rendererPane);
        this.installDefaults();
        this.installListeners();
        this.installKeyboardActions();
    }
    
    protected void installDefaults() {
        LookAndFeel.installColorsAndFont(this.header, "TableHeader.background", "TableHeader.foreground", "TableHeader.font");
        LookAndFeel.installProperty(this.header, "opaque", Boolean.TRUE);
    }
    
    protected void installListeners() {
        this.mouseInputListener = this.createMouseInputListener();
        this.header.addMouseListener(this.mouseInputListener);
        this.header.addMouseMotionListener(this.mouseInputListener);
        this.header.addFocusListener(BasicTableHeaderUI.focusListener);
    }
    
    protected void installKeyboardActions() {
        SwingUtilities.replaceUIInputMap(this.header, 1, (InputMap)DefaultLookup.get(this.header, this, "TableHeader.ancestorInputMap"));
        LazyActionMap.installLazyActionMap(this.header, BasicTableHeaderUI.class, "TableHeader.actionMap");
    }
    
    @Override
    public void uninstallUI(JComponent component) {
        this.uninstallDefaults();
        this.uninstallListeners();
        this.uninstallKeyboardActions();
        this.header.remove(this.rendererPane);
        this.rendererPane = null;
        this.header = null;
    }
    
    protected void uninstallDefaults() {
    }
    
    protected void uninstallListeners() {
        this.header.removeMouseListener(this.mouseInputListener);
        this.header.removeMouseMotionListener(this.mouseInputListener);
        this.mouseInputListener = null;
    }
    
    protected void uninstallKeyboardActions() {
        SwingUtilities.replaceUIInputMap(this.header, 0, null);
        SwingUtilities.replaceUIActionMap(this.header, null);
    }
    
    static void loadActionMap(LazyActionMap lazyActionMap) {
        lazyActionMap.put(new BasicTableHeaderUI.Actions("toggleSortOrder"));
        lazyActionMap.put(new BasicTableHeaderUI.Actions("selectColumnToLeft"));
        lazyActionMap.put(new BasicTableHeaderUI.Actions("selectColumnToRight"));
        lazyActionMap.put(new BasicTableHeaderUI.Actions("moveColumnLeft"));
        lazyActionMap.put(new BasicTableHeaderUI.Actions("moveColumnRight"));
        lazyActionMap.put(new BasicTableHeaderUI.Actions("resizeLeft"));
        lazyActionMap.put(new BasicTableHeaderUI.Actions("resizeRight"));
        lazyActionMap.put(new BasicTableHeaderUI.Actions("focusTable"));
    }
    
    protected int getRolloverColumn() {
        return this.rolloverColumn;
    }
    
    protected void rolloverColumnUpdated(int n, int n2) {
    }
    
    private void updateRolloverColumn(MouseEvent mouseEvent) {
        if (this.header.getDraggedColumn() == null && this.header.contains(mouseEvent.getPoint())) {
            int columnAtPoint = this.header.columnAtPoint(mouseEvent.getPoint());
            if (columnAtPoint != this.rolloverColumn) {
                this.rolloverColumnUpdated(this.rolloverColumn, this.rolloverColumn = columnAtPoint);
            }
        }
    }
    
    private int selectNextColumn(boolean b) {
        int selectedColumnIndex = this.getSelectedColumnIndex();
        if (selectedColumnIndex < this.header.getColumnModel().getColumnCount() - 1) {
            ++selectedColumnIndex;
            if (b) {
                this.selectColumn(selectedColumnIndex);
            }
        }
        return selectedColumnIndex;
    }
    
    private int selectPreviousColumn(boolean b) {
        int selectedColumnIndex = this.getSelectedColumnIndex();
        if (selectedColumnIndex > 0) {
            --selectedColumnIndex;
            if (b) {
                this.selectColumn(selectedColumnIndex);
            }
        }
        return selectedColumnIndex;
    }
    
    void selectColumn(int n) {
        this.selectColumn(n, true);
    }
    
    void selectColumn(int n, boolean b) {
        this.header.repaint(this.header.getHeaderRect(this.selectedColumnIndex));
        this.selectedColumnIndex = n;
        this.header.repaint(this.header.getHeaderRect(n));
        if (b) {
            this.scrollToColumn(n);
        }
    }
    
    private void scrollToColumn(int column) {
        Container parent;
        JTable table;
        if (this.header.getParent() == null || (parent = this.header.getParent().getParent()) == null || !(parent instanceof JScrollPane) || (table = this.header.getTable()) == null) {
            return;
        }
        Rectangle visibleRect = table.getVisibleRect();
        Rectangle cellRect = table.getCellRect(0, column, true);
        visibleRect.x = cellRect.x;
        visibleRect.width = cellRect.width;
        table.scrollRectToVisible(visibleRect);
        return;
    }
    
    private int getSelectedColumnIndex() {
        int columnCount = this.header.getColumnModel().getColumnCount();
        if (this.selectedColumnIndex >= columnCount && columnCount > 0) {
            this.selectedColumnIndex = columnCount - 1;
        }
        return this.selectedColumnIndex;
    }
    
    private static boolean canResize(TableColumn tableColumn, JTableHeader tableHeader) {
        return tableColumn != null && tableHeader.getResizingAllowed() && tableColumn.getResizable();
    }
    
    private int changeColumnWidth(TableColumn tableColumn, JTableHeader tableHeader, int n, int width) {
        tableColumn.setWidth(width);
        Container parent;
        JTable table;
        if (tableHeader.getParent() == null || (parent = tableHeader.getParent().getParent()) == null || !(parent instanceof JScrollPane) || (table = tableHeader.getTable()) == null) {
            return 0;
        }
        if (!parent.getComponentOrientation().isLeftToRight() && !tableHeader.getComponentOrientation().isLeftToRight()) {
            JViewport viewport = ((JScrollPane)parent).getViewport();
            int width2 = viewport.getWidth();
            int n2 = width - n;
            int n3 = table.getWidth() + n2;
            Dimension size = table.getSize();
            size.width += n2;
            table.setSize(size);
            if (n3 >= width2 && table.getAutoResizeMode() == 0) {
                Point viewPosition = viewport.getViewPosition();
                viewPosition.x = Math.max(0, Math.min(n3 - width2, viewPosition.x + n2));
                viewport.setViewPosition(viewPosition);
                return n2;
            }
        }
        return 0;
    }
    
    @Override
    public int getBaseline(JComponent c, int width, int n) {
        super.getBaseline(c, width, n);
        int n2 = -1;
        TableColumnModel columnModel = this.header.getColumnModel();
        for (int i = 0; i < columnModel.getColumnCount(); ++i) {
            columnModel.getColumn(i);
            Component headerRenderer = this.getHeaderRenderer(i);
            int baseline = headerRenderer.getBaseline(headerRenderer.getPreferredSize().width, n);
            if (baseline >= 0) {
                if (n2 == -1) {
                    n2 = baseline;
                }
                else if (n2 != baseline) {
                    n2 = -1;
                    break;
                }
            }
        }
        return n2;
    }
    
    @Override
    public void paint(Graphics graphics, JComponent component) {
        if (this.header.getColumnModel().getColumnCount() <= 0) {
            return;
        }
        int leftToRight = this.header.getComponentOrientation().isLeftToRight();
        Rectangle clipBounds = graphics.getClipBounds();
        Point location = clipBounds.getLocation();
        Point point = new Point(clipBounds.x + clipBounds.width - 1, clipBounds.y);
        TableColumnModel columnModel = this.header.getColumnModel();
        int i = this.header.columnAtPoint(leftToRight ? location : point);
        int j = this.header.columnAtPoint(leftToRight ? point : location);
        if (i == -1) {
            i = 0;
        }
        if (j == -1) {
            j = columnModel.getColumnCount() - 1;
        }
        TableColumn draggedColumn = this.header.getDraggedColumn();
        Rectangle headerRect = this.header.getHeaderRect(leftToRight ? i : j);
        if (!(leftToRight == 0)) {
            int width2;
            for (; i <= j; headerRect.x += width2, ++i) {
                TableColumn column2 = columnModel.getColumn(i);
                width2 = column2.getWidth();
                headerRect.width = width2;
                if (column2 != draggedColumn) {
                    this.paintCell(graphics, headerRect, i);
                }
            }
        }
        else {
            int width;
            for (; j >= i; headerRect.x += width, --j) {
                TableColumn column = columnModel.getColumn(j);
                width = column.getWidth();
                headerRect.width = width;
                if (column != draggedColumn) {
                    this.paintCell(graphics, headerRect, j);
                }
            }
        }
        if (draggedColumn != null) {
            int viewIndexForColumn = this.viewIndexForColumn(draggedColumn);
            Rectangle headerRect2 = this.header.getHeaderRect(viewIndexForColumn);
            graphics.setColor(this.header.getParent().getBackground());
            graphics.fillRect(headerRect2.x, headerRect2.y, headerRect2.width, headerRect2.height);
            headerRect2.x += this.header.getDraggedDistance();
            graphics.setColor(this.header.getBackground());
            graphics.fillRect(headerRect2.x, headerRect2.y, headerRect2.width, headerRect2.height);
            this.paintCell(graphics, headerRect2, viewIndexForColumn);
        }
        this.rendererPane.removeAll();
        return;
    }
    
    private Component getHeaderRenderer(int n) {
        TableColumn column = this.header.getColumnModel().getColumn(n);
        TableCellRenderer tableCellRenderer = column.getHeaderRenderer();
        if (tableCellRenderer == null) {
            tableCellRenderer = this.header.getDefaultRenderer();
        }
        return tableCellRenderer.getTableCellRendererComponent(this.header.getTable(), column.getHeaderValue(), false, !this.header.isPaintingForPrint() && n == this.getSelectedColumnIndex() && this.header.hasFocus(), -1, n);
    }
    
    private void paintCell(Graphics g, Rectangle rectangle, int n) {
        this.rendererPane.paintComponent(g, this.getHeaderRenderer(n), this.header, rectangle.x, rectangle.y, rectangle.width, rectangle.height, true);
    }
    
    private int viewIndexForColumn(TableColumn tableColumn) {
        TableColumnModel columnModel = this.header.getColumnModel();
        int i = 0;
        while (i < columnModel.getColumnCount()) {
            if (columnModel.getColumn(i) == tableColumn) {
                return i;
            }
            ++i;
        }
        return -1;
    }
    
    private int getHeaderHeight() {
        int max = 0;
        int n = 0;
        TableColumnModel columnModel = this.header.getColumnModel();
        for (int i = 0; i < columnModel.getColumnCount(); ++i) {
            TableColumn column = columnModel.getColumn(i);
            int n2 = column.getHeaderRenderer() == null;
            if (n2 == 0 || n == 0) {
                int height = this.getHeaderRenderer(i).getPreferredSize().height;
                max = Math.max(max, height);
                if (n2 && height > 0) {
                    Object headerValue = column.getHeaderValue();
                    if (headerValue != null) {
                        String string = headerValue.toString();
                        if (string != null && !string.equals("")) {
                            n = 1;
                        }
                    }
                }
            }
        }
        return max;
    }
    
    private Dimension createHeaderSize(long n) {
        if (n > 2147483647L) {
            n = 2147483647L;
        }
        return new Dimension((int)n, this.getHeaderHeight());
    }
    
    @Override
    public Dimension getMinimumSize(JComponent component) {
        long n = 0L;
        Enumeration<TableColumn> columns = this.header.getColumnModel().getColumns();
        while (columns.hasMoreElements()) {
            n += (long)((TableColumn)columns.nextElement()).getMinWidth();
        }
        return this.createHeaderSize(n);
    }
    
    @Override
    public Dimension getPreferredSize(JComponent component) {
        long n = 0L;
        Enumeration<TableColumn> columns = this.header.getColumnModel().getColumns();
        while (columns.hasMoreElements()) {
            n += (long)((TableColumn)columns.nextElement()).getPreferredWidth();
        }
        return this.createHeaderSize(n);
    }
    
    @Override
    public Dimension getMaximumSize(JComponent component) {
        long n = 0L;
        Enumeration<TableColumn> columns = this.header.getColumnModel().getColumns();
        while (columns.hasMoreElements()) {
            n += (long)((TableColumn)columns.nextElement()).getMaxWidth();
        }
        return this.createHeaderSize(n);
    }
    
    static int access$000(BasicTableHeaderUI basicTableHeaderUI) {
        return basicTableHeaderUI.getSelectedColumnIndex();
    }
    
    static boolean access$200(TableColumn tableColumn, JTableHeader tableHeader) {
        return canResize(tableColumn, tableHeader);
    }
    
    static void access$400(BasicTableHeaderUI basicTableHeaderUI, MouseEvent mouseEvent) {
        basicTableHeaderUI.updateRolloverColumn(mouseEvent);
    }
    
    static int access$500(BasicTableHeaderUI basicTableHeaderUI, TableColumn tableColumn, JTableHeader tableHeader, int n, int n2) {
        return basicTableHeaderUI.changeColumnWidth(tableColumn, tableHeader, n, n2);
    }
    
    static int access$600(BasicTableHeaderUI basicTableHeaderUI, TableColumn tableColumn) {
        return basicTableHeaderUI.viewIndexForColumn(tableColumn);
    }
    
    static int access$700(BasicTableHeaderUI basicTableHeaderUI, boolean b) {
        return basicTableHeaderUI.selectPreviousColumn(b);
    }
    
    static int access$800(BasicTableHeaderUI basicTableHeaderUI, boolean b) {
        return basicTableHeaderUI.selectNextColumn(b);
    }
    
    static {
        BasicTableHeaderUI.resizeCursor = Cursor.getPredefinedCursor(11);
        BasicTableHeaderUI.focusListener = new FocusListener() {
            @Override
            public void focusGained(FocusEvent focusEvent) {
                this.repaintHeader(focusEvent.getSource());
            }
            
            @Override
            public void focusLost(FocusEvent focusEvent) {
                this.repaintHeader(focusEvent.getSource());
            }
            
            private void repaintHeader(Object o) {
                if ((o instanceof JTableHeader)) {
                    JTableHeader tableHeader = (JTableHeader)o;
                    BasicTableHeaderUI basicTableHeaderUI = (BasicTableHeaderUI)BasicLookAndFeel.getUIOfType(tableHeader.getUI(), BasicTableHeaderUI.class);
                    if (basicTableHeaderUI == null) {
                        return;
                    }
                    tableHeader.repaint(tableHeader.getHeaderRect(BasicTableHeaderUI.access$000(basicTableHeaderUI)));
                }
            }
        };
    }
    
    public class MouseInputHandler implements MouseInputListener
    {
        private int mouseXOffset;
        private Cursor otherCursor;
        
        public MouseInputHandler() {
            this.otherCursor = BasicTableHeaderUI.resizeCursor;
        }
        
        @Override
        public void mouseClicked(MouseEvent anEvent) {
            if (!BasicTableHeaderUI.this.header.isEnabled()) {
                return;
            }
            if (anEvent.getClickCount() % 2 == 1 && SwingUtilities.isLeftMouseButton(anEvent)) {
                JTable table = BasicTableHeaderUI.this.header.getTable();
                RowSorter<Object> rowSorter;
                if (table != null && (rowSorter = table.getRowSorter()) != null) {
                    int columnAtPoint = BasicTableHeaderUI.this.header.columnAtPoint(anEvent.getPoint());
                    if (columnAtPoint != -1) {
                        rowSorter.toggleSortOrder(table.convertColumnIndexToModel(columnAtPoint));
                    }
                }
            }
            return;
        }
        
        private TableColumn getResizingColumn(Point point) {
            return this.getResizingColumn(point, BasicTableHeaderUI.this.header.columnAtPoint(point));
        }
        
        private TableColumn getResizingColumn(Point p2, int column) {
            if (column == -1) {
                return null;
            }
            Rectangle headerRect = BasicTableHeaderUI.this.header.getHeaderRect(column);
            headerRect.grow(-3, 0);
            if (headerRect.contains(p2)) {
                return null;
            }
            int n = headerRect.x + headerRect.width / 2;
            if (BasicTableHeaderUI.this.header.getComponentOrientation().isLeftToRight()) {
                column = ((p2.x < n) ? (column - 1) : column);
            }
            else {
                column = ((p2.x < n) ? column : (column - 1));
            }
            if (column == -1) {
                return null;
            }
            return BasicTableHeaderUI.this.header.getColumnModel().getColumn(column);
        }
        
        @Override
        public void mousePressed(MouseEvent mouseEvent) {
            if (!BasicTableHeaderUI.this.header.isEnabled()) {
                return;
            }
            BasicTableHeaderUI.this.header.setDraggedColumn(null);
            BasicTableHeaderUI.this.header.setResizingColumn(null);
            BasicTableHeaderUI.this.header.setDraggedDistance(0);
            Point point = mouseEvent.getPoint();
            TableColumnModel columnModel = BasicTableHeaderUI.this.header.getColumnModel();
            int columnAtPoint = BasicTableHeaderUI.this.header.columnAtPoint(point);
            if (columnAtPoint != -1) {
                TableColumn resizingColumn = this.getResizingColumn(point, columnAtPoint);
                if (BasicTableHeaderUI.access$200(resizingColumn, BasicTableHeaderUI.this.header)) {
                    BasicTableHeaderUI.this.header.setResizingColumn(resizingColumn);
                    if (BasicTableHeaderUI.this.header.getComponentOrientation().isLeftToRight()) {
                        this.mouseXOffset = point.x - resizingColumn.getWidth();
                    }
                    else {
                        this.mouseXOffset = point.x + resizingColumn.getWidth();
                    }
                }
                else if (BasicTableHeaderUI.this.header.getReorderingAllowed()) {
                    BasicTableHeaderUI.this.header.setDraggedColumn(columnModel.getColumn(columnAtPoint));
                    this.mouseXOffset = point.x;
                }
            }
            if (BasicTableHeaderUI.this.header.getReorderingAllowed()) {
                int access$300 = BasicTableHeaderUI.this.rolloverColumn;
                BasicTableHeaderUI.this.rolloverColumn = -1;
                BasicTableHeaderUI.this.rolloverColumnUpdated(access$300, BasicTableHeaderUI.this.rolloverColumn);
            }
            return;
        }
        
        private void swapCursor() {
            Cursor cursor = BasicTableHeaderUI.this.header.getCursor();
            BasicTableHeaderUI.this.header.setCursor(this.otherCursor);
            this.otherCursor = cursor;
        }
        
        @Override
        public void mouseMoved(MouseEvent mouseEvent) {
            if (!BasicTableHeaderUI.this.header.isEnabled()) {
                return;
            }
            if (BasicTableHeaderUI.access$200(this.getResizingColumn(mouseEvent.getPoint()), BasicTableHeaderUI.this.header) != (BasicTableHeaderUI.this.header.getCursor() == BasicTableHeaderUI.resizeCursor)) {
                this.swapCursor();
            }
            BasicTableHeaderUI.access$400(BasicTableHeaderUI.this, mouseEvent);
            return;
        }
        
        @Override
        public void mouseDragged(MouseEvent mouseEvent) {
            if (!BasicTableHeaderUI.this.header.isEnabled()) {
                return;
            }
            int x = mouseEvent.getX();
            TableColumn resizingColumn = BasicTableHeaderUI.this.header.getResizingColumn();
            TableColumn draggedColumn = BasicTableHeaderUI.this.header.getDraggedColumn();
            int leftToRight = BasicTableHeaderUI.this.header.getComponentOrientation().isLeftToRight();
            if (resizingColumn != null) {
                int width2 = resizingColumn.getWidth();
                int n3;
                if (!(leftToRight == 0)) {
                    n3 = x - this.mouseXOffset;
                }
                else {
                    n3 = this.mouseXOffset - x;
                }
                this.mouseXOffset += BasicTableHeaderUI.access$500(BasicTableHeaderUI.this, resizingColumn, BasicTableHeaderUI.this.header, width2, n3);
            }
            else if (draggedColumn != null) {
                TableColumnModel columnModel = BasicTableHeaderUI.this.header.getColumnModel();
                int a = x - this.mouseXOffset;
                int n = (a < 0) ? -1 : 1;
                int access$600 = BasicTableHeaderUI.access$600(BasicTableHeaderUI.this, draggedColumn);
                int n2 = access$600 + (leftToRight ? n : (-n));
                if (0 <= n2 && n2 < columnModel.getColumnCount()) {
                    int width = columnModel.getColumn(n2).getWidth();
                    if (Math.abs(a) > width / 2) {
                        this.mouseXOffset += n * width;
                        BasicTableHeaderUI.this.header.setDraggedDistance(a - n * width);
                        int convertColumnIndexToModel = SwingUtilities2.convertColumnIndexToModel(BasicTableHeaderUI.this.header.getColumnModel(), BasicTableHeaderUI.access$000(BasicTableHeaderUI.this));
                        columnModel.moveColumn(access$600, n2);
                        BasicTableHeaderUI.this.selectColumn(SwingUtilities2.convertColumnIndexToView(BasicTableHeaderUI.this.header.getColumnModel(), convertColumnIndexToModel), false);
                        return;
                    }
                }
                this.setDraggedDistance(a, access$600);
            }
            BasicTableHeaderUI.access$400(BasicTableHeaderUI.this, mouseEvent);
            return;
        }
        
        @Override
        public void mouseReleased(MouseEvent mouseEvent) {
            if (!BasicTableHeaderUI.this.header.isEnabled()) {
                return;
            }
            this.setDraggedDistance(0, BasicTableHeaderUI.access$600(BasicTableHeaderUI.this, BasicTableHeaderUI.this.header.getDraggedColumn()));
            BasicTableHeaderUI.this.header.setResizingColumn(null);
            BasicTableHeaderUI.this.header.setDraggedColumn(null);
            BasicTableHeaderUI.access$400(BasicTableHeaderUI.this, mouseEvent);
            return;
        }
        
        @Override
        public void mouseEntered(MouseEvent mouseEvent) {
            if (!BasicTableHeaderUI.this.header.isEnabled()) {
                return;
            }
            BasicTableHeaderUI.access$400(BasicTableHeaderUI.this, mouseEvent);
            return;
        }
        
        @Override
        public void mouseExited(MouseEvent mouseEvent) {
            if (!BasicTableHeaderUI.this.header.isEnabled()) {
                return;
            }
            int access$300 = BasicTableHeaderUI.this.rolloverColumn;
            BasicTableHeaderUI.this.rolloverColumn = -1;
            BasicTableHeaderUI.this.rolloverColumnUpdated(access$300, BasicTableHeaderUI.this.rolloverColumn);
            return;
        }
        
        private void setDraggedDistance(int draggedDistance, int n) {
            BasicTableHeaderUI.this.header.setDraggedDistance(draggedDistance);
            if (n != -1) {
                BasicTableHeaderUI.this.header.getColumnModel().moveColumn(n, n);
            }
        }
    }
    
    private static class Actions extends UIAction
    {
        public static final String TOGGLE_SORT_ORDER = "toggleSortOrder";
        public static final String SELECT_COLUMN_TO_LEFT = "selectColumnToLeft";
        public static final String SELECT_COLUMN_TO_RIGHT = "selectColumnToRight";
        public static final String MOVE_COLUMN_LEFT = "moveColumnLeft";
        public static final String MOVE_COLUMN_RIGHT = "moveColumnRight";
        public static final String RESIZE_LEFT = "resizeLeft";
        public static final String RESIZE_RIGHT = "resizeRight";
        public static final String FOCUS_TABLE = "focusTable";
        
        public Actions(String name) {
            super(name);
        }
        
        public boolean isEnabled(Object o) {
            if ((o instanceof JTableHeader)) {
                JTableHeader tableHeader = (JTableHeader)o;
                TableColumnModel columnModel = tableHeader.getColumnModel();
                if (columnModel.getColumnCount() <= 0) {
                    return false;
                }
                String name = this.getName();
                BasicTableHeaderUI basicTableHeaderUI = (BasicTableHeaderUI)BasicLookAndFeel.getUIOfType(tableHeader.getUI(), BasicTableHeaderUI.class);
                if (basicTableHeaderUI != null) {
                    if (name == "moveColumnLeft") {
                        return tableHeader.getReorderingAllowed() && this.maybeMoveColumn(true, tableHeader, basicTableHeaderUI, false);
                    }
                    if (name == "moveColumnRight") {
                        return tableHeader.getReorderingAllowed() && this.maybeMoveColumn(false, tableHeader, basicTableHeaderUI, false);
                    }
                    if (name == "resizeLeft" || name == "resizeRight") {
                        return BasicTableHeaderUI.access$200(columnModel.getColumn(BasicTableHeaderUI.access$000(basicTableHeaderUI)), tableHeader);
                    }
                    if (name == "focusTable") {
                        return tableHeader.getTable() != null;
                    }
                }
            }
            return true;
        }
        
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            JTableHeader tableHeader = (JTableHeader)actionEvent.getSource();
            BasicTableHeaderUI basicTableHeaderUI = (BasicTableHeaderUI)BasicLookAndFeel.getUIOfType(tableHeader.getUI(), BasicTableHeaderUI.class);
            if (basicTableHeaderUI == null) {
                return;
            }
            String name = this.getName();
            if ("toggleSortOrder" == name) {
                JTable table2 = tableHeader.getTable();
                RowSorter<Object> rowSorter = (table2 == null) ? null : table2.getRowSorter();
                if (rowSorter != null) {
                    rowSorter.toggleSortOrder(table2.convertColumnIndexToModel(BasicTableHeaderUI.access$000(basicTableHeaderUI)));
                }
            }
            else if ("selectColumnToLeft" == name) {
                if (tableHeader.getComponentOrientation().isLeftToRight()) {
                    BasicTableHeaderUI.access$700(basicTableHeaderUI, true);
                }
                else {
                    BasicTableHeaderUI.access$800(basicTableHeaderUI, true);
                }
            }
            else if ("selectColumnToRight" == name) {
                if (tableHeader.getComponentOrientation().isLeftToRight()) {
                    BasicTableHeaderUI.access$800(basicTableHeaderUI, true);
                }
                else {
                    BasicTableHeaderUI.access$700(basicTableHeaderUI, true);
                }
            }
            else if ("moveColumnLeft" == name) {
                this.moveColumn(true, tableHeader, basicTableHeaderUI);
            }
            else if ("moveColumnRight" == name) {
                this.moveColumn(false, tableHeader, basicTableHeaderUI);
            }
            else if ("resizeLeft" == name) {
                this.resize(true, tableHeader, basicTableHeaderUI);
            }
            else if ("resizeRight" == name) {
                this.resize(false, tableHeader, basicTableHeaderUI);
            }
            else if ("focusTable" == name) {
                JTable table = tableHeader.getTable();
                if (table != null) {
                    table.requestFocusInWindow();
                }
            }
            return;
        }
        
        private void moveColumn(boolean b, JTableHeader tableHeader, BasicTableHeaderUI basicTableHeaderUI) {
            this.maybeMoveColumn(b, tableHeader, basicTableHeaderUI, true);
        }
        
        private boolean maybeMoveColumn(boolean b, JTableHeader tableHeader, BasicTableHeaderUI basicTableHeaderUI, boolean b2) {
            int access$000 = BasicTableHeaderUI.access$000(basicTableHeaderUI);
            int n;
            if (tableHeader.getComponentOrientation().isLeftToRight()) {
                n = (b ? BasicTableHeaderUI.access$700(basicTableHeaderUI, b2) : BasicTableHeaderUI.access$800(basicTableHeaderUI, b2));
            }
            else {
                n = (b ? BasicTableHeaderUI.access$800(basicTableHeaderUI, b2) : BasicTableHeaderUI.access$700(basicTableHeaderUI, b2));
            }
            if (n != access$000) {
                if (b2) {
                    tableHeader.getColumnModel().moveColumn(access$000, n);
                }
                else {
                    return true;
                }
            }
            return false;
        }
        
        private void resize(boolean b, JTableHeader tableHeader, BasicTableHeaderUI basicTableHeaderUI) {
            TableColumn column = tableHeader.getColumnModel().getColumn(BasicTableHeaderUI.access$000(basicTableHeaderUI));
            tableHeader.setResizingColumn(column);
            int width = column.getWidth();
            int n;
            if (tableHeader.getComponentOrientation().isLeftToRight()) {
                n = width + (b ? -1 : 1);
            }
            else {
                n = width + (b ? 1 : -1);
            }
            BasicTableHeaderUI.access$500(basicTableHeaderUI, column, tableHeader, width, n);
        }
    }
}
